@@ -19,6 +19,7 @@ from requests.auth import HTTPBasicAuth
 
 
 class Project():
+    default_directory: Directory
 
     def __init__(
             self,
@@ -112,6 +113,13 @@ class Project():
 
         return self.label_schema_list[0]
 
+    def get_connection_list(self):
+        url = f'/api/project/{self.project_string_id}/connections'
+        response = self.session.get(url = self.host + url)
+        self.handle_errors(response)
+        data = response.json()
+        return data.get('connection_list')
+
     def get_label_list(self, schema_id = None):
         url = f'/api/project/{self.project_string_id}/labels'
         if schema_id is None:
@@ -327,6 +335,23 @@ class Project():
         self.session.headers.update(
             {'directory_id': str(self.directory_id)})
 
+
+
+    def new_schema(self,
+                   name: str):
+
+            endpoint = "/api/v1/project/" + self.project_string_id + \
+                       "/labels-schema/new"
+
+            request_json_body = {'name': name}
+
+            response = self.session.post(self.host + endpoint,
+                                         json = request_json_body)
+
+            self.handle_errors(response)
+            return response.json()
+
+
 # TODO review not using this pattern anymore
 
 setattr(Project, "get_label_file_dict", get_label_file_dict)
