@@ -70,6 +70,8 @@ class Directory(DiffgramDatasetIterator):
             )
             refresh_from_dict(new_directory, directory_json)
 
+            new_directory.id = new_directory.directory_id
+
             # note timing issue, this needs to happen after id is refreshed
             new_directory.init_files()
             new_directory.start_iterator(
@@ -194,9 +196,10 @@ class Directory(DiffgramDatasetIterator):
         # Confirm not in existing
         # generator expression returns True if the directory
         # is not found. this is a bit awkward.
-        if next((dir for dir in self.client.directory_list
-                 if dir.nickname == name), True) is not True:
-            raise Exception(name, "Already exists")
+        if self.client.directory_list:
+            if next((dir for dir in self.client.directory_list
+                     if dir.nickname == name), True) is not True:
+                raise Exception(name, "Already exists")
 
         packet = {'nickname': name}
 
